#define STATUS "-stable"		/* stable branch */
#if 0
#define STATUS ""			/* release */
#define STATUS "-beta"			/* just before a release */
#define STATUS "-current"		/* just after a release */
#endif

const char ostype[] = "OpenBSD";
const char osrelease[] = "7.0";
const char osversion[] = "RDROOT#1";
const char sccs[] =
    "    @(#)OpenBSD 7.0" STATUS " (RDROOT) #1: Sun Oct 31 13:56:22 JST 2021\n";
const char version[512] =
    "OpenBSD 7.0" STATUS " (RDROOT) #1: Sun Oct 31 13:56:22 JST 2021\n    root@nimbus12.localnet:/opt/fi/7.0/sys/arch/i386/compile/RDROOT\n";
